# -*- coding: utf-8 -*-
import os
from dspawpy.plot import plot_dos
from dspawpy.io.read import get_dos_data
from pymatgen.electronic_structure.plotter import DosPlotter

dos_data = get_dos_data(
    dos_dir="dspawpy_proj/dspawpy_tests/inputs/3.2.4/dos.h5",  # 读取投影态密度数据
    return_dos=False,  # 如果为False，则统一返回CompleteDos对象（无论计算时是否开了投影）
)
dos_plotter = DosPlotter(
    zero_at_efermi=True,  # 是否将费米能级作为零点
    stack=False,  # True表示绘制面积图
    sigma=None,  # 高斯展宽，None表示不进行平滑处理
)
# print(dos_data.structure)

# ! 指定原子序号，从0开始
ais = [1]

print("正在绘图...")
atom_indices = [int(ai) for ai in ais]
for atom_index in atom_indices:
    dos_plotter.add_dos_dict(
        dos_data.get_site_t2g_eg_resolved_dos(dos_data.structure[atom_index])
    )

ax = plot_dos(
    dosplotter=dos_plotter,
    xlim=[-10, 5],  # 设置能量范围
    ylim=None,  # 设置态密度范围
)
ax.axhline(0, lw=2, ls="-.", color="gray")

filename = (
    "dspawpy_proj/dspawpy_tests/outputs/us/5dos_t2g_eg.png"  # 输出的态密度图文件名
)
os.makedirs(os.path.dirname(os.path.abspath(filename)), exist_ok=True)

fig = ax.get_figure()
fig.savefig(filename, dpi=300)
